#version 330 core

const vec3 light_position_worldspace = vec3(0.8, 0.05, 1); // Light position in world space.
const float ambientIntensity = 0.05f;

uniform mat4 u_model;
uniform mat4 u_view;

uniform mat3 u_normalMatrix;
uniform vec4 u_color;

uniform vec3 u_lightPos;
uniform vec3 u_diffuseColor;
uniform vec3 u_specColor;
uniform float u_shininess;

in vec3 a_position;
in vec3 a_normal;
in vec2 a_texCoords;

flat out vec3 color;
out vec3 normalWorldspace;

void main()
{
    mat4 mv = u_view * u_model;

    // Convert light dir and normal to worldspace
    normalWorldspace          = normalize(u_normalMatrix * a_normal);
    vec3 position_worldspace  = vec3(mv * vec4(a_position, 1));
    vec3 lightdir_worldspace  = normalize(light_position_worldspace - position_worldspace);

    // diffuse with lambert
    float diffuse = clamp(dot( lightdir_worldspace, normalWorldspace ), 0.0, 1.0);
    float light_intensity = clamp(ambientIntensity + diffuse, 0.0, 1.0);

    color = u_color.rgb * light_intensity;

    // Convert position to world space and pass along
    gl_Position = mv * vec4(a_position, 1.0);
}
